#!/bin/bash

if [ "$1" == "" ]; then
    echo "$0: Please provide a directory name as the first parameter"
    exit 1
fi
if [ ! -d "$1" ]; then
    echo "$0: $1 is not a directory name"
    exit 2
fi


#if [ "$2" == "" ]; then
#    echo "$0: Please provide a run output filename as the second parameter"
#    exit 1
#fi
#if [ ! -f "$2" ]; then
#    echo "$0: $1 is not a file name"
#    exit 2
#fi


TGT_DIR=$1

# Find a valid XML config file. The path and name can be deduced from the _info.txt file.
INFO_FIELDS=(`head -n 2 ${TGT_DIR}/_info.txt | tail -n 1 | tr ';' "\n"`)
XML_FILE=${TGT_DIR}/${INFO_FIELDS[3]}/${INFO_FIELDS[2]}.config.xml
if [ ! -f ${XML_FILE} ]; then
    # INFO_FIELDS[3] probably contains the original name of the simulation directory
    XML_FILE=`realpath -s ${TGT_DIR}/../${INFO_FIELDS[3]}/${INFO_FIELDS[2]}.config.xml`
fi
if [ ! -f ${XML_FILE} ]; then
    echo "ERROR: ${XML_FILE} not found"
    exit 10
fi

# Read the start date and number of iterations from the XML config file
XPATH='//config/module[@name="episim"]/param[@name="startDate"]/@value'
DATE_START=`xmllint --xpath "string(${XPATH})" ${XML_FILE}`
ITERATIONS=`cat ${TGT_DIR}/iterations`
DATE_END=`date '+%C%y-%m-%d' -d "$DATE_START +$ITERATIONS days"`

echo "Simulation start date: $DATE_START"
echo "Simulation end date:   $DATE_END"

# Replace dates in the metadata.yaml file
YAML_FILE=${TGT_DIR}/metadata.yaml
if [ ! -f $YAML_FILE ]; then
    echo "ERROR: $YAML_FILE not found"
    exit 20
fi
YAML_TIMESTAMP=`grep -oP 'timestamp: \K([0-9]{4}-[0-9]{2}-[0-9]{2})' $YAML_FILE`

sed -i "s/defaultStartDate: $YAML_TIMESTAMP/defaultStartDate: $DATE_START/" $YAML_FILE
# Replace only on lines following the startDates line
START_DATES_LINE=`grep startDates -n $YAML_FILE | cut -d ':' -f 1`
#sed -i "$START_DATES_LINE s/- $YAML_TIMESTAMP/- $DATE_START/" $YAML_FILE
sed -i "s/- $YAML_TIMESTAMP/- $DATE_START/" $YAML_FILE

sed -i "s/endDate: null/endDate: $DATE_END/" $YAML_FILE


