#!/bin/bash

if [ "$1" == "" ]; then
    echo "$0: Please provide a directory name"
    exit 1
fi
if [ ! -d "$1" ]; then
    echo "$0: $1 is not a directory name"
    exit 2
fi

TGT_DIR=$1

COLLECT_SH="/path/to/matsim-episim-libs/battery/v16/calibration/dresden/collect.sh"
AGGREGATE_PY="/path/to/matsim-episim-libs/src/main/python/"

RUN_DIR=`pwd`



echo "~~ Creating summaries"
cd "$TGT_DIR"
${COLLECT_SH} Dresden
cd ${RUN_DIR}
echo "~~ done"



echo "~~ Aggregating summaries"

PYTHON_MODULE="python/3.9.6"

# Save the state of loaded modules
ORIGINAL_COLLECTION=""
if ! module list |& grep 'No modules loaded'; then # Lmod `module list` outputs to STDERR only
    ORIGINAL_COLLECTION="temp-episim-upload-saved"
    module --force save $ORIGINAL_COLLECTION
    module purge
fi

# Load a known working python module
module load ${PYTHON_MODULE}

# Run the aggregation script
SUMMARIES=${TGT_DIR}/summaries_snapshot.zip
PYTHONPATH=${AGGREGATE_PY}:$PYTHONPATH \
    python -c "from analysis.utils import aggregate_batch_run; aggregate_batch_run('${SUMMARIES}')"

# Restore the state of loaded modules
module purge
module restore $ORIGINAL_COLLECTION

echo "~~ done"

