#!/bin/bash

KEYFILE="$HOME/.ssh/upload_id_ed25519"
EXPORT_DIRECTORY="/path/to/episim-web-export/upload"

if [ "$1" == "" ]; then
    echo "$0: Please provide a directory name"
    exit 1
fi
if [ ! -d "$1" ]; then
    echo "$0: $1 is not a directory name"
    exit 2
fi

if [ ! -f $KEYFILE ]; then
    echo "Upload keyfile $KEYFILE not found. Please install the upload keys for your user."
    exit 3
fi

# Sanitize the directory name keeping only alnum and -_ characters from the last directory
NORMALIZED=`basename "${1}" | sed -e 's/[^A-Za-z0-9_-]/_/g'`

# Set up directory names
SRC_DIR="${1}"
EXP_TRIMMED=`echo "${EXPORT_DIRECTORY}" | sed 's:/*$::'`    # Remove trailing slashes
EXP_DIR=${EXPORT_DIRECTORY}/${NORMALIZED}

# Check if the export directory exists and create it if not
if [ -s "${EXP_DIR}" ]; then
    echo "WARNING: ${EXP_DIR} already exists."
    echo "         Existing files will be overwritten."
    #TODO: Also delete the source directory if we're sure the path is safe
else
    mkdir -p "${EXP_DIR}" \
        || {
            echo "ERROR: Could not create ${EXP_DIR}"
            exit 6
        }
fi

FILES="_info.txt metadata.yaml summaries_snapshot.zip summaries_snapshot-aggr.zip"

# Copy to export directory
echo "Copying files to export directory '${EXP_DIR}'" 
for F in ${FILES}; do
    cp -r ${SRC_DIR}/${F} ${EXP_DIR}/${F}
done

# Upload to the web server
DEPLOY_TARGET="episim-deploy@vlsweb6b:"
echo "Uploading to '${DEPLOY_TARGET}'"
rsync -e "ssh -i ${KEYFILE}" -ra --info=progress2 ${EXP_DIR} ${DEPLOY_TARGET}

echo
echo "Normalized upload directory name:"
echo
echo "NORMALIZED='${NORMALIZED}'"

