#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import pandas as pd
import numpy as np
import os

import matplotlib.pyplot as plt

import psycopg2
from psycopg2 import Error
import pandas as pd
import matplotlib.pyplot as plt
import csv


# Connection to the Postgresql database
param_dic = {
    "user":"",
    "password":"",
    "host":"",
    "port":"",
    "database":""
}

win_roll = 12

output_file = os.environ['csv_file']
svn_output_file = os.environ['svn_output_file']

#Define a function
def connect(params_dic):
    """ Connect to the PostgreSQL database server """
    conn = None
    try:
        # connect to the PostgreSQL server
        print('Connecting to the PostgreSQL database...')
        conn = psycopg2.connect(**params_dic)
    except (Exception, psycopg2.DatabaseError) as error:
        print(error)
        sys.exit(1) 
    print("Connection successful")
    return conn

#Function to display the data frame.
def postgresql_to_dataframe(conn, select_query, column_names):
    """
    Tranform a SELECT query into a pandas dataframe
    """
    cursor = conn.cursor()
    try:
        cursor.execute(select_query)
    except (Exception, psycopg2.DatabaseError) as error:
        print("Error: %s" % error)
        cursor.close()
        return 1
    
    # Naturally we get a list of tupples
    tupples = cursor.fetchall()
    cursor.close()
    
    # We just need to turn it into a pandas dataframe
    df = pd.DataFrame(tupples, columns=column_names)
    return df

conn = connect(param_dic)
column_names = ["date", "incidence", "hospitalized", "intensive_care", "dead", "population"]
df_data = postgresql_to_dataframe(conn, "SELECT * from view_dresden_infected_hospitalised_dead_daily", column_names)
date = df_data["date"]
df_data["date"] = pd.to_datetime(date).dt.strftime('%d.%m.%Y')

hospitalized = df_data["hospitalized"]
#hospitalized_per_100k = hospitalized / df_data["population"] * 100000 * 10
#df_data["hospitalized"] = hospitalized_per_100k.rolling(window=win_roll).mean()
df_data["hospitalized"] = hospitalized.rolling(window=win_roll).mean()
df_data["Susceptible"] = df_data["population"] - df_data["incidence"].cumsum()

df_data.drop("population", axis=1).to_csv(output_file, index=False)
#df_data.to_csv(output_file, index=False)


svn_column_names=["Datum", "Jahr", "Monat", "Tag", "Laborbestätigte Fälle (Meldedatum)", "Laborbestätigte Fälle (kumuliert)", "Laborbestätigte Fälle (übermittelt)", "Einweisung Krankenhaus", "Einweisung Krankenhaus (kumuliert)", "Sterbefälle", "Sterbefälle (kumuliert)", "Genesene (geschätzt)", "Genesene (geschätzt, kumuliert)"]

svn_jahr = pd.to_datetime(date).dt.strftime('%Y')
svn_monat = pd.to_datetime(date).dt.strftime('%m')
svn_tag = pd.to_datetime(date).dt.strftime('%d')

zeros = df_data["incidence"] - df_data["incidence"]
svn_lfm = df_data["incidence"]
svn_lfk = svn_lfm.cumsum()
svn_lfu = zeros
svn_ek = hospitalized              # raw
#svn_ek = df_data["hospitalized"]    # rolling window
svn_ekk = svn_ek.cumsum()
svn_sf = df_data["dead"]
svn_sfk = svn_sf.cumsum()
svn_gg = zeros
svn_ggk = zeros

svn_df_data = pd.DataFrame(
        list(zip(date, svn_jahr, svn_monat, svn_tag, svn_lfm, svn_lfk, svn_lfu, svn_ek, svn_ekk, svn_sf, svn_sfk, svn_gg, svn_ggk)),
        columns=svn_column_names)
svn_df_data.to_csv(svn_output_file, index=False, sep=';', quoting=csv.QUOTE_NONNUMERIC)





