#!/bin/bash
#
# You can have only one forced command in ~/.ssh/authorized_keys.
# Instead of a command, the remote user enters a parameter to be 
# read by this script as if it were the actual command. The parameter
# is then taken to be the name of the upload directory.

UPLOAD_DIR=/home/episim-deploy/upload-temp
DEPLOY_DIR=/var/www/where2test.de/covid-sim-data/dresden


# Split original command on spaces, we'll only keep the first word
read -a PARAMS <<< "$SSH_ORIGINAL_COMMAND"

if [ ${#PARAMS[@]} -eq 0 ]; then
	echo "ERROR: No paramters passed via SSH!"
	exit 5
fi

echo
echo "-- Webserver $HOST running deployment script:"
echo

# Sanitize the directory name
DIRNAME=`sed -e 's/[^A-Za-z0-9_-]/_/g' <<< "${PARAMS[0]}"`

UPLOAD=${UPLOAD_DIR}/$DIRNAME
DEPLOY=${DEPLOY_DIR}/$DIRNAME

echo "UPLOAD=${UPLOAD}"
echo "DEPLOY=${DEPLOY}"

echo "Copying uploaded files..."
if [ ! -d $UPLOAD ]; then
	echo "ERROR: Upload directory ${UPLOAD}"
	echo "does not exist on the server."
	echo "Check if your data was uploaded correctly."
	exit 6
fi

if [ -d $DEPLOY ]; then
	echo "WARNING: Deploy directory ${DEPLOY}"
	echo "already exists on the server."
	echo "Old data will be overwritten!"
	cp -r ${UPLOAD}/* $DEPLOY && rm -r ${UPLOAD}
else
	cp -r $UPLOAD $DEPLOY
fi

pushd $DEPLOY
echo "Unpacking summaries..."
#unzip -o summaries_snapshot.zip
unzip -o summaries_snapshot-aggr.zip
echo "Fixing aggregate metadata.yaml"
# Will delete both whole lines regardless of which one starts with a dash
sed -i '/measure: seed/d' metadata.yaml
sed -i '/title: Seed/d' metadata.yaml


popd

echo "Fixing file permissions..."
chmod -R a+rX $DEPLOY
chmod -R ug+rwX $DEPLOY

echo
echo "-- Webserver $HOST done."
echo

